@@ -5,21 +5,21 @@ use strict;
 use warnings;
 
 sub description { 'Google Groups: https://groups.google.com' }
-sub make {
+sub inquire {
     # Detect an error from Google Groups
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [Undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to parse or the arguments are missing
     # @since v4.25.6
     my $class = shift;
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
 
-    return undef unless rindex($mhead->{'from'}, '<mailer-daemon@googlemail.com>') > -1;
-    return undef unless index($mhead->{'subject'}, 'Delivery Status Notification') > -1;
+    return undef unless rindex($mhead->{'from'}, '<mailer-daemon@googlemail.com>')  > -1;
+    return undef unless  index($mhead->{'subject'}, 'Delivery Status Notification') > -1;
     return undef unless exists $mhead->{'x-failed-recipients'};
-    return undef unless index($mhead->{'x-failed-recipients'}, '@googlegroups.com') > -1;
+    return undef unless exists $mhead->{'x-google-smtp-source'};
 
     # Hello kijitora@libsisimai.org,
     #
@@ -39,10 +39,10 @@ sub make {
     #
     # Google Groups
     state $indicators = __PACKAGE__->INDICATORS;
-    state $rebackbone = qr/^-----[ ]Original[ ]message[ ]-----$/m;
+    state $boundaries = ['----- Original message -----'];
 
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
-    my $emailsteak = Sisimai::RFC5322->fillet($mbody, $rebackbone);
+    my $emailparts = Sisimai::RFC5322->part($mbody, $boundaries);
     my $recordwide = { 'rhost' => '', 'reason' => '', 'diagnosis' => '' };
     my $recipients = 0;
     my $v = $dscontents->[-1];
@@ -51,20 +51,19 @@ sub make {
     # * The owner of the group may have removed this group.
     # * You may need to join the group before receiving permission to post.
     # * This group may not be open to posting.
-    my $fewdetails = [$emailsteak->[0] =~ /^[ ]?[*][ ]?/gm] || [];
+    my $fewdetails = [$emailparts->[0] =~ /^[ ]?[*][ ]?/gm] || [];
     $recordwide->{'reason'} = scalar @$fewdetails == 4 ? 'rejected' : 'onhold';
 
-    my @entiremesg = split(/\n\n/, $emailsteak->[0], 5); pop @entiremesg;
-    my $diagnostic = join(' ', @entiremesg); $diagnostic =~ y/\n/ /;
-    $recordwide->{'diagnosis'} = Sisimai::String->sweep($diagnostic);
+    my @entiremesg = split(/\n\n/, $emailparts->[0], 5); pop @entiremesg;
+    my $issuedcode = join(' ', @entiremesg); $issuedcode =~ y/\n/ /;
+    $recordwide->{'diagnosis'} = Sisimai::String->sweep($issuedcode);
 
     my $serverlist = Sisimai::RFC5322->received($mhead->{'received'}->[0]);
     $recordwide->{'rhost'} = shift @$serverlist;
 
     for my $e ( split(',', $mhead->{'x-failed-recipients'}) ) {
         # X-Failed-Recipients: neko@example.jp, nyaan@example.org, ...
-        next unless index($e, '@googlegroups.com') > -1;
-        next unless Sisimai::RFC5322->is_emailaddress($e);
+        next unless Sisimai::Address->is_emailaddress($e);
 
         if( $v->{'recipient'} ) {
             # There are multiple recipient addresses in the message body.
@@ -76,7 +75,7 @@ sub make {
         $v->{ $_ } = $recordwide->{ $_ } for keys %$recordwide;
     }
     return undef unless $recipients;
-    return { 'ds' => $dscontents, 'rfc822' => $emailsteak->[1] };
+    return { 'ds' => $dscontents, 'rfc822' => $emailparts->[1] };
 }
 
 1;
@@ -94,8 +93,8 @@ Sisimai::Lhost::GoogleGroups - bounce mail parser class for C<Google Groups>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::GoogleGroups parses a bounce email which created by C<Gmail>.
-Methods in the module are called from only Sisimai::Message.
+Sisimai::Lhost::GoogleGroups parses a bounce email which created by C<Google Groups>. Methods in the
+module are called from only Sisimai::Message.
 
 =head1 CLASS METHODS
 
@@ -105,10 +104,10 @@ C<description()> returns description string of this module.
 
     print Sisimai::Lhost::GoogleGroups->description;
 
-=head2 C<B<make(I<header data>, I<reference to body string>)>>
+=head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<make()> method parses a bounced email and return results as a array reference.
-See Sisimai::Message for more details.
+C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
+for more details.
 
 =head1 AUTHOR
 
@@ -116,7 +115,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2020 azumakuniyuki, All rights reserved.
+Copyright (C) 2020-2023 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
