@@ -5,12 +5,12 @@ use strict;
 use warnings;
 
 sub description { 'Yandex.Mail: https://www.yandex.ru' }
-sub make {
+sub inquire {
     # Detect an error from Yandex.Mail
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [Undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to parse or the arguments are missing
     # @since v4.1.6
     my $class = shift;
     my $mhead = shift // return undef;
@@ -26,25 +26,24 @@ sub make {
     return undef unless $mhead->{'x-yandex-uniq'};
     return undef unless $mhead->{'from'} eq 'mailer-daemon@yandex.ru';
 
+    require Sisimai::SMTP::Command;
     state $indicators = __PACKAGE__->INDICATORS;
-    state $rebackbone = qr|^Content-Type:[ ]message/rfc822|m;
+    state $boundaries = ['Content-Type: message/rfc822'];
     state $startingof = { 'message' => ['This is the mail system at host yandex.ru.'] };
 
-    require Sisimai::RFC1894;
     my $fieldtable = Sisimai::RFC1894->FIELDTABLE;
     my $permessage = {};    # (Hash) Store values of each Per-Message field
-
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
-    my $emailsteak = Sisimai::RFC5322->fillet($mbody, $rebackbone);
+    my $emailparts = Sisimai::RFC5322->part($mbody, $boundaries);
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my @commandset;         # (Array) ``in reply to * command'' list
     my $v = undef;
     my $p = '';
 
-    for my $e ( split("\n", $emailsteak->[0]) ) {
-        # Read error messages and delivery status lines from the head of the email
-        # to the previous line of the beginning of the original message.
+    for my $e ( split("\n", $emailparts->[0]) ) {
+        # Read error messages and delivery status lines from the head of the email to the previous
+        # line of the beginning of the original message.
         unless( $readcursor ) {
             # Beginning of the bounce message or message/delivery-status part
             $readcursor |= $indicators->{'deliverystatus'} if index($e, $startingof->{'message'}->[0]) == 0;
@@ -93,19 +92,16 @@ sub make {
             # <kijitora@example.jp>: host mx.example.jp[192.0.2.153] said: 550
             #    5.1.1 <kijitora@example.jp>... User Unknown (in reply to RCPT TO
             #    command)
-            if( $e =~ /[ \t][(]in reply to .*([A-Z]{4}).*/ ) {
+            if( index($e, ' (in reply to ') > -1 || index($e, 'command)') > -1 ) {
                 # 5.1.1 <userunknown@example.co.jp>... User Unknown (in reply to RCPT TO
-                push @commandset, $1;
-
-            } elsif( $e =~ /([A-Z]{4})[ \t]*.*command[)]\z/ ) {
-                # to MAIL command)
-                push @commandset, $1;
+                my $cv = Sisimai::SMTP::Command->find($e);
+                push @commandset, $cv if $cv;
 
             } else {
                 # Continued line of the value of Diagnostic-Code field
                 next unless index($p, 'Diagnostic-Code:') == 0;
-                next unless $e =~ /\A[ \t]+(.+)\z/;
-                $v->{'diagnosis'} .= ' '.$1;
+                next unless index($e, ' ') == 0;
+                $v->{'diagnosis'} .= ' '.Sisimai::String->sweep($e);
             }
         }
     } continue {
@@ -117,12 +113,12 @@ sub make {
     for my $e ( @$dscontents ) {
         # Set default values if each value is empty.
         $e->{'lhost'} ||= $permessage->{'rhost'};
-        $e->{ $_ } ||= $permessage->{ $_ } || '' for keys %$permessage;
-        $e->{'command'}   =  shift @commandset || '';
+        $e->{ $_ }    ||= $permessage->{ $_ } || '' for keys %$permessage;
         $e->{'diagnosis'} =~ y/\n/ /;
         $e->{'diagnosis'} =  Sisimai::String->sweep($e->{'diagnosis'});
+        $e->{'command'} ||=  shift @commandset || Sisimai::SMTP::Command->find($e->{'diagnosis'}) || '';
     }
-    return { 'ds' => $dscontents, 'rfc822' => $emailsteak->[1] };
+    return { 'ds' => $dscontents, 'rfc822' => $emailparts->[1] };
 }
 
 1;
@@ -140,8 +136,8 @@ Sisimai::Lhost::Yandex - bounce mail parser class for C<Yandex.Mail>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::Yandex parses a bounce email which created by C<Yandex.Mail>.
-Methods in the module are called from only Sisimai::Message.
+Sisimai::Lhost::Yandex parses a bounce email which created by C<Yandex.Mail>. Methods in the module
+are called from only Sisimai::Message.
 
 =head1 CLASS METHODS
 
@@ -151,10 +147,10 @@ C<description()> returns description string of this module.
 
     print Sisimai::Lhost::Yandex->description;
 
-=head2 C<B<make(I<header data>, I<reference to body string>)>>
+=head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<make()> method parses a bounced email and return results as a array reference.
-See Sisimai::Message for more details.
+C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
+for more details.
 
 =head1 AUTHOR
 
@@ -162,7 +158,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2020 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2021,2023 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
