@@ -10,7 +10,8 @@ sub make {
     # @return        [Array]        Order of MTA modules
     # @since         v4.25.4
     my $class = shift;
-    my $argv0 = shift || return [];
+    my $argv0 = shift || return []; y/_[] / /s, s/\A[ ]+// for $argv0;
+    my @words = split(/[ ]/, lc($argv0), 3);
     my $first = '';
 
     # The following order is decided by the first 2 words of Subject: header
@@ -64,9 +65,11 @@ sub make {
         'message-delivery' => ['Sisimai::Lhost::MailFoundry'],
         'message-frozen'   => ['Sisimai::Lhost::Exim'],
         'message-you'      => ['Sisimai::Lhost::Barracuda'],
+        'não-entregue'     => ['Sisimai::Lhost::Office365'],
         'non-recapitabile' => ['Sisimai::Lhost::Exchange2007'],
         'non-remis' => ['Sisimai::Lhost::Exchange2007'],
         'notice'    => ['Sisimai::Lhost::Courier'],
+        'onbestelbaar'       => ['Sisimai::Lhost::Office365'],
         'permanent-delivery' => ['Sisimai::Lhost::X4'],
         'postmaster-notify'  => ['Sisimai::Lhost::Sendmail'],
         'returned-mail' => [
@@ -100,14 +103,9 @@ sub make {
         'warning' => ['Sisimai::Lhost::Sendmail', 'Sisimai::Lhost::Exim'],
     };
 
-
-    $argv0 =~ y/_[] / /s;
-    $argv0 =~ s/\A[ ]+//;
-    my @words = split(/[ ]/, lc($argv0), 3);
-
     if( rindex($words[0], ':') > 0 ) {
         # Undeliverable: ..., notify: ...
-        $first = lc $1 if $argv0 =~ /\A(.+?):/;
+        $first = lc substr($argv0, 0, index($argv0, ':'));
 
     } else {
         # Postmaster notify, returned mail, ...
@@ -121,7 +119,7 @@ sub default {
     # Make default order of MTA modules to be loaded
     # @return   [Array] Default order list of MTA modules
     # @since v4.13.1
-    return [map { 'Sisimai::Lhost::'.$_ } @{ Sisimai::Lhost->index() }];
+    return [map { 'Sisimai::Lhost::'.$_ } Sisimai::Lhost->index()->@*];
 }
 
 sub another {
@@ -129,8 +127,8 @@ sub another {
     # @return   [Array] Ordered module list
     # @since v4.13.1
 
-    # There are another patterns in the value of "Subject:" header of a bounce mail
-    # generated by the following MTA/ESP modules
+    # There are another patterns in the value of "Subject:" header of a bounce mail generated by the
+    # following MTA modules
     state $orderE0 = [
         'Sisimai::Lhost::MailRu',
         'Sisimai::Lhost::Yandex',
@@ -203,8 +201,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Order - A Class for making an optimized order list for calling MTA
-modules in Sisimai::Lhost::*.
+Sisimai::Order - A Class for making an optimized order list for calling MTA modules in Sisimai::Lhost::*.
 
 =head1 SYNOPSIS
 
@@ -212,25 +209,25 @@ modules in Sisimai::Lhost::*.
 
 =head1 DESCRIPTION
 
-Sisimai::Order class makes optimized order list which include MTA modules to be
-loaded on first from MTA specific headers in the bounce mail headers such as
-X-Failed-Recipients, which MTA modules for JSON structure.
+Sisimai::Order class makes optimized order list which include MTA modules to be loaded on first from
+MTA specific headers in the bounce mail headers such as X-Failed-Recipients, which MTA modules for
+JSON structure.
 
 =head1 CLASS METHODS
 
 =head2 C<B<default()>>
 
-C<default()> returns a default order of MTA modules as an array reference. The
-default order is defined at Sisimai::Lhost->index method.
+C<default()> returns a default order of MTA modules as an array reference. The default order is
+defined at Sisimai::Lhost->index method.
 
-    print for @{ Sisimai::Order->default };
+    print for Sisimai::Order->default->@*;
 
 =head2 C<B<another()>>
 
-C<another()> returns another list of MTA modules as an array reference. Another
-list is defined at this class.
+C<another()> returns another list of MTA modules as an array reference. Another list is defined at
+this class.
 
-    print for @{ Sisimai::Order->another };
+    print for Sisimai::Order->another->@*;
 
 =head1 AUTHOR
 
@@ -238,7 +235,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2015-2017,2019,2020 azumakuniyuki, All rights reserved.
+Copyright (C) 2015-2017,2019-2023 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
