@@ -17,10 +17,13 @@ sub match {
     state $index = [
         ' is currently suspended',
         ' temporary locked',
+        'archived recipient',
         'boite du destinataire archivee',
         'email account that you tried to reach is disabled',
+        'has been suspended',
         'invalid/inactive user',
         'is a deactivated mailbox', # http://service.mail.qq.com/cgi-bin/help?subtype=1&&id=20022&&no=1000742
+        'is unavailable: user is terminated',
         'mailbox currently suspended',
         'mailbox is frozen',
         'mailbox unavailable or access denied',
@@ -37,17 +40,18 @@ sub match {
 
 sub true {
     # The envelope recipient's mailbox is suspended or not
-    # @param    [Sisimai::Data] argvs   Object to be detected the reason
+    # @param    [Sisimai::Fact] argvs   Object to be detected the reason
     # @return   [Integer]               1: is mailbox suspended
     #                                   0: is not suspended
     # @since v4.0.0
     # @see http://www.ietf.org/rfc/rfc2822.txt
     my $class = shift;
     my $argvs = shift // return undef;
-    return undef unless $argvs->deliverystatus;
+    return undef unless $argvs->{'deliverystatus'};
 
-    return 1 if $argvs->reason eq 'suspend';
-    return 1 if __PACKAGE__->match(lc $argvs->diagnosticcode);
+    return 1 if $argvs->{'reason'} eq 'suspend';
+    return 1 if length $argvs->{'replycode'} && $argvs->{'replycode'} == 525;
+    return 1 if __PACKAGE__->match(lc $argvs->{'diagnosticcode'});
     return 0
 }
 
@@ -67,11 +71,9 @@ Sisimai::Reason::Suspend - Bounce reason is C<suspend> or not.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::Suspend checks the bounce reason is C<suspend> or not. This
-class is called only Sisimai::Reason class.
-
-This is the error that a recipient account is being suspended due to unpaid or
-other reasons.
+Sisimai::Reason::Suspend checks the bounce reason is C<suspend> or not. This class is called only
+Sisimai::Reason class. This is the error that a recipient account is being suspended due to unpaid
+or other reasons.
 
 =head1 CLASS METHODS
 
@@ -87,10 +89,10 @@ C<match()> returns 1 if the argument matched with patterns defined in this class
 
     print Sisimai::Reason::Suspend->match('recipient suspend the service'); # 1
 
-=head2 C<B<true(I<Sisimai::Data>)>>
+=head2 C<B<true(I<Sisimai::Fact>)>>
 
-C<true()> returns 1 if the bounce reason is C<suspend>. The argument must be
-Sisimai::Data object and this method is called only from Sisimai::Reason class.
+C<true()> returns 1 if the bounce reason is C<suspend>. The argument must be Sisimai::Fact object
+and this method is called only from Sisimai::Reason class.
 
 =head1 AUTHOR
 
@@ -98,7 +100,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2019 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2021,2023 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
