@@ -13,7 +13,8 @@ sub match {
     # @since v4.1.26
     my $class = shift;
     my $argv1 = shift // return undef;
-    my $index = [
+
+    state $index = [
         'all available ips are at maximum connection limit',    # SendGrid
         'connection rate limit exceeded',
         'exceeds per-domain connection limit for',
@@ -24,18 +25,18 @@ sub match {
         'too many connections from your host.', # Microsoft
         'too many concurrent smtp connections', # Microsoft
         'too many errors from your ip',         # Free.fr
+        'too many recipients',                  # ntt docomo
         'too many smtp sessions for this host', # Sendmail(daemon.c)
         'trop de connexions, ',
         'we have already made numerous attempts to deliver this message',
     ];
-
     return 1 if grep { rindex($argv1, $_) > -1 } @$index;
     return 0;
 }
 
 sub true {
     # Blocked due to that connection rate limit exceeded
-    # @param    [Sisimai::Data] argvs   Object to be detected the reason
+    # @param    [Sisimai::Fact] argvs   Object to be detected the reason
     # @return   [Integer]               1: Too many connections(blocked)
     #                                   0: Not many connections
     # @since v4.1.26
@@ -43,12 +44,9 @@ sub true {
     my $class = shift;
     my $argvs = shift // return undef;
 
-    return undef unless ref $argvs eq 'Sisimai::Data';
-    return 1 if $argvs->reason eq 'toomanyconn';
-
-    require Sisimai::SMTP::Status;
-    return 1 if Sisimai::SMTP::Status->name($argvs->deliverystatus) eq 'toomanyconn';
-    return 1 if __PACKAGE__->match(lc $argvs->diagnosticcode);
+    return 1 if $argvs->{'reason'} eq 'toomanyconn';
+    return 1 if (Sisimai::SMTP::Status->name($argvs->{'deliverystatus'}) || '') eq 'toomanyconn';
+    return 1 if __PACKAGE__->match(lc $argvs->{'diagnosticcode'});
     return 0;
 }
 
@@ -68,12 +66,11 @@ Sisimai::Reason::TooManyConn - Bounced due to that too many connections.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::TooManyConn checks the bounce reason is C<toomanyconn> or not.
-This class is called only Sisimai::Reason class.
+Sisimai::Reason::TooManyConn checks the bounce reason is C<toomanyconn> or not. This class is called
+only Sisimai::Reason class.
 
-This is the error that SMTP connection was rejected temporarily due to too many
-concurrency connections to the remote server. This reason has added in Sisimai
-4.1.26 and does not exist in any version of bounceHammer.
+This is the error that SMTP connection was rejected temporarily due to too many concurrency connections
+to the remote server. This reason has added in Sisimai 4.1.26.
 
     <kijitora@example.ne.jp>: host mx02.example.ne.jp[192.0.1.20] said:
         452 4.3.2 Connection rate limit exceeded. (in reply to MAIL FROM command)
@@ -92,10 +89,10 @@ C<match()> returns 1 if the argument matched with patterns defined in this class
 
     print Sisimai::Reason::TooManyConn->match('Connection rate limit exceeded');  # 1
 
-=head2 C<B<true(I<Sisimai::Data>)>>
+=head2 C<B<true(I<Sisimai::Fact>)>>
 
-C<true()> returns 1 if the bounce reason is C<toomanyconn>. The argument must be
-Sisimai::Data object and this method is called only from Sisimai::Reason class.
+C<true()> returns 1 if the bounce reason is C<toomanyconn>. The argument must be Sisimai::Fact
+object and this method is called only from Sisimai::Reason class.
 
 =head1 AUTHOR
 
@@ -103,7 +100,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2018 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2021 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
