@@ -5,11 +5,11 @@ use warnings;
 
 sub get {
     # Detect bounce reason from Orange and La Poste
-    # @param    [Sisimai::Data] argvs   Parsed email object
+    # @param    [Sisimai::Fact] argvs   Parsed email object
     # @return   [String]                The bounce reason for Orange, La Poste
     my $class = shift;
     my $argvs = shift // return undef;
-    return $argvs->reason if $argvs->reason;
+    return $argvs->{'reason'} if $argvs->{'reason'};
 
     state $errorcodes = {
         # 550 5.7.1 Service unavailable; client [X.X.X.X] blocked using Spamhaus
@@ -127,15 +127,19 @@ sub get {
         # Message refuse, verification DMARC en echec LPN007_517
         '517' => 'policyviolation',
 
+        # 554 5.7.1 Client host rejected
+        # LPN000_630
+        '630' => 'policyviolation',
+
         # 421 mwinf5c77 ME Service refuse. Veuillez essayer plus tard.
         # Service refused, please try later. OFR_999 [999]
         '999' => 'blocked',
     };
 
-    my $statusmesg = $argvs->diagnosticcode;
+    my $issuedcode = $argvs->{'diagnosticcode'};
     my $reasontext = '';
 
-    if( $statusmesg =~ /\b(LPN|LPNAAA|OFR|OUK)(_[0-9]{3}|[0-9]{3}[-_][0-9]{3})\b/i ) {
+    if( $issuedcode =~ /\b(LPN|LPNAAA|OFR|OUK)(_[0-9]{3}|[0-9]{3}[-_][0-9]{3})\b/i ) {
         # OUK_513, LPN105-104, OFR102-104, ofr_506
         my $v = sprintf("%03d", substr($1.$2, -3, 3));
         $reasontext = $errorcodes->{ $v } || 'undefined';
@@ -150,8 +154,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Rhost::FrancePTT - Detect the bounce reason returned from Orange and
-La Poste.
+Sisimai::Rhost::FrancePTT - Detect the bounce reason returned from Orange and La Poste.
 
 =head1 SYNOPSIS
 
@@ -159,14 +162,13 @@ La Poste.
 
 =head1 DESCRIPTION
 
-Sisimai::Rhost detects the bounce reason from the content of Sisimai::Data
-object as an argument of get() method when the value of C<rhost> of the object
-end with "laposte.net" or "orange.fr".
-This class is called only Sisimai::Data class.
+Sisimai::Rhost detects the bounce reason from the content of Sisimai::Fact object as an argument
+of get() method when the value of C<rhost> of the object end with "laposte.net" or "orange.fr".
+This class is called only Sisimai::Fact class.
 
 =head1 CLASS METHODS
 
-=head2 C<B<get(I<Sisimai::Data Object>)>>
+=head2 C<B<get(I<Sisimai::Fact Object>)>>
 
 C<get()> detects the bounce reason.
 
@@ -176,7 +178,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2017-2020 azumakuniyuki, All rights reserved.
+Copyright (C) 2017-2021,2023 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
